function [Ceqdef,Jacdef] = DefSep_NN(nvar,into,colind,scl,def)

%
% Written by Julian Straus, Trondheim 09.12.2018
% 
% This function defines the definition values in the reaction
% section of the simple ammonia loop. It can be modified to define the
% flowsheet differently. The definitions in this file are given by:
%
%   Cold and hot inlet HEx6     Q, p, T, and xi
%
% The input of this function is given by
%       nvar:   Total number of variables.
%
%       into:   Input values to the unit operation defined in the
%               flowsheet.
%
%       colind: Indexes of the columns i the Jacobian.
%
% The main output is defined as
%       Ceqdef: Cells containing the equality constraints of the
%               definitions.
%
%       Jacdef: Cells containing the rows of the Jacobian defined by the
%               definitions.
%
% The necessary structures and cells are defined as
%       scl:    Scaling factors of the system defined in cells representing
%               the unit operations defined in par.ReactSec.
%
%       def:    Defined stream values, e.g pressure and composition for all
%               inlets and the pressure of the outlets or the flow of the
%               inlets.

% Predefinition of the returning cells.
Jacdef = cell(size(into));
Ceqdef = Jacdef;
                                  
%% Definitions in Heat Exchanger 6

k = 1;
% Calculation of the equality constraints for the definition of heat exchanger 1
Ceqdef{k+1} = [into{k}(1:8).*scl{k+20}.Var(1:8)'-def.FSep;...
               into{k}(17:24).*scl{k+20}.Var(17:24)'-def.HEx6;...
               into{k}(41).*scl{k+20}.Var(41)'-def.Sratio{1}(2);...
               into{k}(42:44).*scl{k+20}.Var(42:44)'-def.Tref'].*scl{k+20}.DefEq;

% Calculation of the parts of the Jacobian defined by the definition of
% heat exchanger 1
colind{k+1} = colind{k}([1:8 17:24 41:44]);
Jacdef{k+1} = sparse(1:numel(Ceqdef{k+1}),colind{k+1},scl{k+20}.DefEq'.*scl{k+20}.Var([1:8 17:24 41:44]),...
                     numel(Ceqdef{k+1}),nvar);

%% Definitions in Split 3

k = 7;
% Calculation of the equality constraints for the definition of split 3
Ceqdef{k+1} = (into{k}(26).*scl{k}.Var(26)'-def.Sratio{2}(2)).*scl{k}.DefEq;

% Calculation of the parts of the Jacobian defined by the definition of
% split 3
colind{k+1} = colind{k}(25);
Jacdef{k+1} = sparse(1:numel(Ceqdef{k+1}),colind{k+1},scl{k}.DefEq.*scl{k}.Var(26),...
                     numel(Ceqdef{k+1}),nvar);
